Index: trunk/MagicSoft/Mars/mbase/BaseLinkDef.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/BaseLinkDef.h	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/BaseLinkDef.h	(revision 1540)
@@ -35,4 +35,5 @@
 #pragma link C++ class MClone+;
 #pragma link C++ class MPrint+;
+#pragma link C++ class MContinue+;
 
 #pragma link C++ class MArray;
Index: trunk/MagicSoft/Mars/mbase/MClone.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MClone.h	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MClone.h	(revision 1540)
@@ -30,5 +30,6 @@
     Bool_t Process();
 
-    TObject *GetClone() const { return fClone; }
+    TObject *GetClone() const  { return fClone; }
+    const TObject *GetObject() const { return fObject; }
 
     void Clear(Option_t *opt=NULL);
Index: trunk/MagicSoft/Mars/mbase/MEvtLoop.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MEvtLoop.cc	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MEvtLoop.cc	(revision 1540)
@@ -86,4 +86,5 @@
 #ifdef __MARS__
 #include "MReadTree.h"       // for setting progress bar
+#include "MProgressBar.h"    // MProgressBar::GetBar
 #endif
 
@@ -126,4 +127,16 @@
     enable ? SetBit(kIsOwner) : ResetBit(kIsOwner);
 }
+
+#ifdef __MARS__
+// --------------------------------------------------------------------------
+//
+//  Specify an existing MProgressBar object. It will display the progress
+//  graphically. This will make thing about 1-2% slower.
+//
+void MEvtLoop::SetProgressBar(MProgressBar *bar)
+{
+    fProgress = bar->GetBar();
+}
+#endif
 
 // --------------------------------------------------------------------------
Index: trunk/MagicSoft/Mars/mbase/MEvtLoop.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MEvtLoop.h	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MEvtLoop.h	(revision 1540)
@@ -17,4 +17,7 @@
 class MTaskList;
 class TGProgressBar;
+#ifdef __MARS__
+class MProgressBar;
+#endif
 
 class MEvtLoop : public MParContainer
@@ -44,4 +47,7 @@
 
     void SetProgressBar(TGProgressBar *bar) { fProgress = bar; }
+#ifdef __MARS__
+    void SetProgressBar(MProgressBar *bar);
+#endif
 
     Bool_t PreProcess(const char *tlist="MTaskList");
Index: trunk/MagicSoft/Mars/mbase/MTaskList.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MTaskList.cc	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MTaskList.cc	(revision 1540)
@@ -66,4 +66,5 @@
 #include "MLogManip.h"
 
+#include "MFilter.h"
 #include "MParList.h"
 #include "MInputStreamID.h"
@@ -71,6 +72,7 @@
 ClassImp(MTaskList);
 
-static const TString gsDefName  = "MTaskList";
-static const TString gsDefTitle = "A list for tasks to be executed";
+const TString MTaskList::gsDefName  = "MTaskList";
+const TString MTaskList::gsDefTitle = "A list for tasks to be executed";
+
 // --------------------------------------------------------------------------
 //
@@ -492,5 +494,7 @@
 //  For convinience the lvl argument results in a number of spaces at the
 //  beginning of the line. So that the structur of a tasklist can be
-//  identified. Use MTaskList::PrintStatistics without an argument.
+//  identified. If a Tasklist or task has filter applied the name of the
+//  filter is printer in <>-brackets behind the number of executions.
+//  Use MTaskList::PrintStatistics without an argument.
 //
 void MTaskList::PrintStatistics(const Int_t lvl, Bool_t title) const
@@ -502,4 +506,6 @@
         *fLog << "---------------------" << endl;
         *fLog << GetDescriptor();
+        if (GetFilter())
+            *fLog << " <" << GetFilter()->GetName() << ">";
         if (title)
             *fLog << "\t" << fTitle;
Index: trunk/MagicSoft/Mars/mbase/MTaskList.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MTaskList.h	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MTaskList.h	(revision 1540)
@@ -21,10 +21,10 @@
 {
 private:
-    TList    *fTasks;	    // Container for the ordered list of different tasks
-    TList    fTasksProcess; //!
-    MParList *fParList;     //!
+    static const TString gsDefName;  // default name
+    static const TString gsDefTitle; // default title
 
-    UInt_t *fCntContinue;   //!
-    UInt_t *fCntTrue;       //!
+    TList    *fTasks;        // Container for the ordered list of different tasks
+    TList     fTasksProcess; //! Task which overload the Process function
+    MParList *fParList;      //! The parameter list given in PreProcess
 
     enum { kIsOwner = BIT(14) };
Index: trunk/MagicSoft/Mars/mbase/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mbase/Makefile	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/Makefile	(revision 1540)
@@ -20,5 +20,5 @@
 # @endcode 
 
-INCLUDES = -I. -I../mraw -I../MRawFormat -I../mmc -I../mfileio
+INCLUDES = -I. -I../mraw -I../MRawFormat -I../mmc -I../mfileio -I../mmain
 
 # @code 
@@ -48,4 +48,5 @@
            MTime.cc \
            MClone.cc \
+           MContinue.cc \
            MPrint.cc \
            MLogManip.cc

Index: trunk/MagicSoft/Mars/mbase/MTask.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MTask.cc	(revision 1538)
+++ trunk/MagicSoft/Mars/mbase/MTask.cc	(revision 1540)
@@ -252,8 +252,10 @@
 // --------------------------------------------------------------------------
 //
 // Prints the number of times this task has been processed.
 // For convinience the lvl argument results in a number of spaces at the
 // beginning of the line. So that the structur of a tasklist can be
 // identified.
 //
 void MTask::PrintStatistics(const Int_t lvl, Bool_t title) const
@@ -261,4 +263,6 @@
     *fLog << all << setw(lvl) << " " << GetDescriptor() << "\t";
     *fLog << dec << fNumExecutions;
+    if (fFilter)
+        *fLog << " <" << fFilter->GetName() << ">";
     if (title)
         *fLog << "\t" << fTitle;
@@ -280,6 +284,6 @@
     /*
      If we don't stream filter which are not in the task list itself
-     (which means: alrteady streamed) we may be able to use the
-     primitive streamer as some kind of validity check for the macros
+     (which means: already streamed) we may be able to use
+     SavePrimitive as some kind of validity check for the macros
 
      fFilter->SavePrimitive(out);
@@ -252,8 +252,10 @@
 // --------------------------------------------------------------------------
 //
-// Prints the number of times this task has been processed.
-// For convinience the lvl argument results in a number of spaces at the
-// beginning of the line. So that the structur of a tasklist can be
-// identified.
+//  Prints the number of times all the tasks in the list has been.
+//  For convinience the lvl argument results in a number of spaces at the
+//  beginning of the line. So that the structur of a tasklist can be
+//  identified. If a Tasklist or task has filter applied the name of the
+//  filter is printer in <>-brackets behind the number of executions.
+//  Use MTaskList::PrintStatistics without an argument.
 //
 void MTask::PrintStatistics(const Int_t lvl, Bool_t title) const